@@ -20,23 +20,22 @@
 // 27.4.3 fpos
 
 #include <iterator>
+#include <limits>
 #include <testsuite_hooks.h>
 
-// libstdc++/14320
 void test01()
 {
   using namespace std;
-  bool test __attribute__((unused)) = true;
+  bool test __attribute__((unused)) = true;  
 
-  typedef std::istreambuf_iterator<char>::difference_type Distance;
-  Distance d = 2;
-  Distance e = 3;
-  d *= e;
-  VERIFY( static_cast<int>(d) == 6 );
+  typedef istreambuf_iterator<char>::difference_type Distance;
+  typedef numeric_limits<Distance> Limits;
+
+  VERIFY( Limits::is_specialized );
+  VERIFY( Limits::is_signed );
 }
 
 int main()
 {
   test01();
-  return 0;
 }
